@@ -1,7 +1,7 @@
 #' Calculate abundances/counts of specific features for a VDJ dataframe
 #'
 #'@description Calculate the absolute counts or proportions of a specific cell-level feature (column in the VDJ/VDJ.GEX.matrix[[1]] object), per an optional specific grouping factor (e.g., clonotype via 'clonotype_id') and an optional sample factor(e.g., 'sample_id'). Outputs either a count dataframe of the specific feature or a ggplot2 barplot.
-#' @param VDJ VDJ or VDJ.GEX.matrix[[1]] object, as obtained from the VDJ_GEX_matrix function in Platypus.
+#' @param VDJ VDJ or VDJ.GEX.matrix[[1]] object, as obtained from the VDJ_build or VDJ_GEX_matrix function in Platypus.
 #' @param feature.columns vector of strings, denoting the columns of the VDJ/VDJ.GEX.matrix[[1]] object from which to extract the unique feature values (for which we will calculate the counts or proportions).
 #' @param proportions string, 'absolute' will return the absolute counts, 'group.level.proportions' will return the counts divided by the total number or elements/values in the specific groups (group level proportions), 'sample.level.proportions' will return the counts divided by the total number of elements in the sample.
 #' @param specific.features vector of specific feature values (or NULL) for which to calculate counts/proportions, from the specified feature.columns parameter (only works if a single feature column is specified in feature.columns).
@@ -23,7 +23,7 @@
 #'or a barplot of the counts/proportions per feature, per group.
 #' @export
 #' @examples
-#' VDJ_abundances(VDJ = Platypus::small_vgm[[1]],
+#' VDJ_abundances(VDJ = Platypus::small_vdj,
 #' feature.columns='VDJ_cgene', proportions='absolute',
 #' grouping.column='clonotype_id', specific.groups='none',
 #' output.format='plot')
@@ -298,10 +298,11 @@ VDJ_abundances <- function(VDJ,
    stop("The provided grouping.column was not found in VDJ. Please provide a valid name or 'none' to avoid grouping")
   }
 
-  if(VDJ.VJ.1chain==TRUE){
-    VDJ <- VDJ[which(VDJ$Nr_of_VDJ_chains==1 & VDJ$Nr_of_VDJ_chains==1),]
-  }
 
+  if(VDJ.VJ.1chain==TRUE){
+    VDJ <- VDJ[which(VDJ$VDJ_chain_count ==1 & VDJ$VJ_chain_count ==1),]
+  }
+  print(VDJ)
 
 
   if(grouping.column=='none'){
@@ -356,6 +357,7 @@ VDJ_abundances <- function(VDJ,
      all_feature_dfs <- list()
      for(j in 1:length(feature.columns)){
        single_feature_dfs <- lapply(unique_groups, function(x) get_count_df_for_group(df=sample_dfs[[i]], group=x, feature=feature.columns[[j]]))
+
        single_feature_dfs <- single_feature_dfs[!sapply(single_feature_dfs,is.null)]
        all_feature_dfs[[j]] <- do.call('rbind', single_feature_dfs)
 
