@@ -1,55 +1,72 @@
-#' Minimal version of the VDJ building part from VDJ_GEX_matrix() function. Optimized for for Cell Ranger v7 and suitable for older Cell Ranger versions.
-#' @description  Minimal version of the VDJ building part from VDJ_GEX_matrix() function. Adapted for Cell Ranger v7 and older versions as well. Currently, Seurat objects need to be integrated by matching barcodes from the Seurat object's metadata with the barcodes of the VDJ dataframe.
-#' Authors: Valentijn Tromp, Tudor-Stefan Cotet, Victor Kreiner, Aurora Desideri Perea, Evgenios Kladis, Anamay Samant
-#' @param VDJ.directory string - path to parent directory containing the output folders (one folder for each sample) of Cell Ranger. This pipeline assumes that the output file names have not been changed from the default 10x settings in the /outs/ folder. This is compatible with B and T cell repertoires. ! Neccessary 5 files within this folder: 'filtered_contig_annotations.csv', 'filtered_contig.fasta', 'consensus_annotations.csv', 'consensus.fasta', and 'concat_ref.fasta'.
-#' @param VDJ.sample.list list - list of paths to the output folders (one folder for each sample) of Cell Ranger. This pipeline assumes that the output file names have not been changed from the default 10x settings in the /outs/ folder. This is compatible with B and T cell repertoires. ! Neccessary 5 files within this folder: 'filtered_contig_annotations.csv', 'filtered_contig.fasta', 'consensus_annotations.csv', 'consensus.fasta', and 'concat_ref.fasta'.
-#' @param remove.divergent.cells bool - if TRUE, cells with more than one VDJ transcript or more than one VJ transcript will be excluded. This could be due to multiple cells being trapped in one droplet or due to light chain dual expression (concerns ~2-5\% of B cells, see DOI:10.1084/jem.181.3.1245). Defaults to FALSE.
-#' @param complete.cells.only bool - if TRUE, only cells with both a VDJ transcripts and a VJ transcript are included in the VDJ dataframe. Keeping only cells with 1 VDJ and 1 VJ transcript could be preferable for downstream analysis. Defaults to FALSE.
-#' @param trim.germlines bool - if TRUE, the raw germline sequences of each clone will be trimmed using the the consensus sequences of that clone as reference seqeunces (using BIostrings::pairwiseAlignment with the option "global-local" and a gap opening cost = gap.opening.cost). Defaults to FALSE.
-#' @param gap.opening.cost float or Inf - the cost for opening a gap in Biostrings::pairwiseAlignment when aligning and trimming germline sequences. Defaults to Inf (gapless alignment).
-#' @param parallel bool - if TRUE, the per-sample VDJ building is executed in parallel (parallelized across samples). Defaults to FALSE.
-#' @param num.cores integer - number of cores to be used when parallel = TRUE. Defaults to all available cores - 1 or the number of sample folders in 'VDJ.directory' (depending which number is smaller).
-
-#' @return Returns the VDJ dataframe / VGM[[1]] object.
+#' Minimal Version of the VDJ Building Part from VDJ_GEX_matrix() Function
+#'
+#' This function imports Cell Ranger output into an R dataframe for downstream analyses. It is a minimal version of the VDJ building part from the `VDJ_GEX_matrix()` function of the Platypus package, adapted for Cell Ranger v7 and older versions. Seurat objects can be integrated by matching barcodes from the Seurat object's metadata with the barcodes in the `barcode` column of the VDJ dataframe.
+#'
+#' @param VDJ.directory A string specifying the path to the parent directory containing the output folders (one folder for each sample) of Cell Ranger. This pipeline assumes that the output file names have not been changed from the default 10x settings in the `/outs/` folder. This is compatible with B and T cell repertoires. The following 5 files are necessary within this folder: 
+#' \describe{
+#'   \item{`filtered_contig_annotations.csv`}{Contains the filtered contig annotations.}
+#'   \item{`filtered_contig.fasta`}{Contains the filtered contig sequences in FASTA format.}
+#'   \item{`consensus_annotations.csv`}{Contains the consensus annotations.}
+#'   \item{`consensus.fasta`}{Contains the consensus sequences in FASTA format.}
+#'   \item{`concat_ref.fasta`}{Contains concatenated reference sequences.}
+#' }
+#' @param VDJ.sample.list A list specifying the paths to the output folders (one folder for each sample) of Cell Ranger. This pipeline assumes that the output file names have not been changed from the default 10x settings in the `/outs/` folder and requires the same 5 files listed above.
+#' @param remove.divergent.cells A logical value (`TRUE`/`FALSE`). If `TRUE`, cells with more than one VDJ transcript or more than one VJ transcript will be excluded. This could be due to multiple cells being trapped in one droplet or light chain dual expression (concerns ~2-5 percent of B cells, see DOI:10.1084/jem.181.3.1245). Defaults to `FALSE`.
+#' @param complete.cells.only A logical value (`TRUE`/`FALSE`). If `TRUE`, only cells with both a VDJ transcript and a VJ transcript are included in the VDJ dataframe. Keeping only cells with 1 VDJ and 1 VJ transcript could be preferable for downstream analysis. Defaults to `FALSE`.
+#' @param trim.germlines A logical value (`TRUE`/`FALSE`). If `TRUE`, the raw germline sequences of each clone will be trimmed using the consensus sequences of that clone as reference sequences (using `Biostrings::pairwiseAlignment` with the option "global-local" and a gap opening cost specified by `gap.opening.cost`). Defaults to `FALSE`.
+#' @param gap.opening.cost A numeric value representing the cost for opening a gap in `Biostrings::pairwiseAlignment` when aligning and trimming germline sequences. Defaults to 10.
+#' @param parallel A logical value (`TRUE`/`FALSE`). If `TRUE`, the per-sample VDJ building is executed in parallel (parallelized across samples). Defaults to `FALSE`.
+#' @param num.cores An integer specifying the number of cores to be used when `parallel = TRUE`. Defaults to all available cores minus 1 or the number of sample folders in `VDJ.directory` (whichever is smaller).
+#'
+#' @return A dataframe representing the VDJ / VGM[[1]] object. Each row in this dataframe represents one cell or one unique cell barcode.
+#'
+#' @details The function extracts and processes VDJ data from Cell Ranger output folders, making it suitable for integration with downstream analysis workflows such as Seurat. It can handle both T and B cell repertoires and is optimized for Cell Ranger v7.
+#'
 #' @export
-
+#' 
 #' @examples
-#'\donttest{
-#'try({
-#' VDJ <- VDJ_build(VDJ_directory)
+#' \donttest{
+#' try({
+#'   VDJ <- VDJ_build(
+#'     VDJ.directory = "path/to/VDJ_directory",
+#'     remove.divergent.cells = TRUE,
+#'     complete.cells.only = TRUE,
+#'     trim.germlines = TRUE
+#'   )
 #' })
-#'}
+#' }
+
+
 
 
 VDJ_build <- function(VDJ.directory,
-                VDJ.sample.list,
-                remove.divergent.cells,
-                complete.cells.only,
-                trim.germlines,
-                gap.opening.cost,
-                parallel,
-                num.cores){
+                      VDJ.sample.list,
+                      remove.divergent.cells,
+                      complete.cells.only,
+                      trim.germlines,
+                      gap.opening.cost,
+                      parallel,
+                      num.cores){
 
 
   # If both the 'VDJ.directory' and 'VDJ.sample.list' are missing, a message is returned and execution is stopped
-  if(missing(VDJ.directory) & missing(VDJ.sample.list)){stop('The path to the parent directory containing the output folders (one for each sample) from Cell Ranger or the list of sample directories are missing.')}
+  if(missing(VDJ.directory) & missing(VDJ.sample.list)){stop('The path to the parent directory containing the output folders (one for each sample) from Cell Ranger, or the list of these sample directories are missing.')}
   # If both a 'VDJ.directory' and 'VDJ.sample.list' are specified, a message is returned and execution is stopped
   if(!missing(VDJ.directory) & !missing(VDJ.sample.list)){stop('Both a path to the parent directory containing the output folders (one for each sample) from Cell Ranger and a list of sample directories are given as input. Please provide one parent direcotry or one list of sample directories.')}
-
+  
+  #Set defaults
+  if(missing(remove.divergent.cells)){remove.divergent.cells <- FALSE}
+  if(missing(complete.cells.only)){complete.cells.only <- FALSE}
+  if(missing(trim.germlines)){trim.germlines <- FALSE}
+  if(missing(gap.opening.cost)){gap.opening.cost <- 10}
+  if(missing(parallel)){parallel <- FALSE}
+  
   # Create list with paths to output folders of Cell Ranger (one path for each sample) in parent direcotry 'VDJ.directory'
   if(missing(VDJ.sample.list)){
     VDJ.sample.list <- list.dirs(path=VDJ.directory,
                                  full.names=T,
                                  recursive=F)
   }
-  if(missing(complete.cells.only)) complete.cells.only <- FALSE
-  if(missing(remove.divergent.cells)) remove.divergent.cells <- FALSE
-  if(missing(trim.germlines)) trim.germlines <- FALSE
-  if(missing(gap.opening.cost)) gap.opening.cost <- Inf
-  if(missing(parallel)) parallel <- FALSE
-  if(missing(num.cores)) num.cores <- NULL
-
-
   # Add a '/' at the end of each directory (if not already present)
   VDJ.sample.list <- sub("/?$", "/", VDJ.sample.list)
 
@@ -61,17 +78,20 @@ VDJ_build <- function(VDJ.directory,
   # Return a message that performing pairwise alignment for all germline sequences significantly increases computation time (if 'trim.germlines' is set to TRUE)
   if(trim.germlines){message("Warning: Setting 'trim.germlines' to TRUE will significantly increase computation time, please be patient!\n")}
 
-
-  #Set all global variables to NULL - CRAN fixes
+  #Global variable definitions for CRAN checks
   sequence_trimmed <- NULL
   chain <- NULL
   barcode <- NULL
+  barcode <- NULL
   VDJ_clonotype_id <- NULL
   VJ_clonotype_id <- NULL
   VDJ_chain_count <- NULL
   VJ_chain_count <- NULL
+  celltype <- NULL
+  VDJ_cgene <- NULL
   clonotype_id <- NULL
 
+  
 
   get_trim_seqs_from_json <- function(annotation_file){
 
@@ -105,7 +125,7 @@ VDJ_build <- function(VDJ.directory,
           # Retrieve contig/consensus ID
           id = single_annotation$contig_name,
           # Trim raw sequence using 'L-REGION+V-REGION' start and 'J-REGION' end indices
-          sequence_trimmed = substr(single_annotation$sequence,
+          sequence_trimmed <- substr(single_annotation$sequence,
                                     start = as.numeric(lv_region$contig_match_start)+1,
                                     stop = as.numeric(j_region$contig_match_end))
         )
@@ -127,13 +147,13 @@ VDJ_build <- function(VDJ.directory,
   }
 
 
-  trim_seq <- function(seq1, seq2, gap.opening.cost = Inf){
+  trim_seq <- function(seq1, seq2, gap.opening.cost = 10){
 
     # Perform global-local alignment with seq1 and seq2 and thereby trim seq2 (subject) using seq1 (pattern)
     # Arguments:
     # - seq1: sequence used as reference during pairwise alignment
     # - seq2: sequence that will be trimmeded during pairwise alignment
-    # - gap.opening.cost: cost for opening a gap in Biostrings::pairwiseAlignment (defaults to Inf for gapless alignments, as suggested by Anamay Saman)
+    # - gap.opening.cost: cost for opening a gap in Biostrings::pairwiseAlignment
     # Authors: Evgenios Kladis, Valentijn Tromp
 
     # If 'seq1' or 'seq2' is missing, an empty string is returned
@@ -152,6 +172,61 @@ VDJ_build <- function(VDJ.directory,
     }
   }
 
+  translate_DNA<- function(sequence){
+
+    #Translate a nucleotide sequence into an amino acid sequence
+    #Arguments:
+    #- sequence: nucleotide sequence to be translated
+
+    if (sequence == ""){
+      return("")
+    }
+
+    #Genetic code
+    genetic_code <- list(
+      "TTT"="F", "TTC"="F", "TTA"="L", "TTG"="L",
+      "TCT"="S", "TCC"="S", "TCA"="S", "TCG"="S",
+      "TAT"="Y", "TAC"="Y", "TAA"="*", "TAG"="*",
+      "TGT"="C", "TGC"="C", "TGA"="*", "TGG"="W",
+      "CTT"="L", "CTC"="L", "CTA"="L", "CTG"="L",
+      "CCT"="P", "CCC"="P", "CCA"="P", "CCG"="P",
+      "CAT"="H", "CAC"="H", "CAA"="Q", "CAG"="Q",
+      "CGT"="R", "CGC"="R", "CGA"="R", "CGG"="R",
+      "ATT"="I", "ATC"="I", "ATA"="I", "ATG"="M",
+      "ACT"="T", "ACC"="T", "ACA"="T", "ACG"="T",
+      "AAT"="N", "AAC"="N", "AAA"="K", "AAG"="K",
+      "AGT"="S", "AGC"="S", "AGA"="R", "AGG"="R",
+      "GTT"="V", "GTC"="V", "GTA"="V", "GTG"="V",
+      "GCT"="A", "GCC"="A", "GCA"="A", "GCG"="A",
+      "GAT"="D", "GAC"="D", "GAA"="E", "GAG"="E",
+      "GGT"="G", "GGC"="G", "GGA"="G", "GGG"="G"
+    )
+    #Split the sequence into codons
+    codons <- strsplit(sequence, "(?<=.{3})", perl=TRUE)[[1]]
+
+    #Translate the codons
+    for (codon_id in 1:length(codons)){
+      #Remove codons that are not complete
+      if(nchar(codons[codon_id]) < 3){
+        codons[codon_id] = ""
+      }
+      #Codons that contain "-" are replaced with "-"
+      else if (grepl("-", codons[codon_id], fixed = TRUE)){
+        codons[codon_id] = "-"
+      }
+      #Translate codons according to the genetic code
+      else{
+        codons[codon_id] = genetic_code[[codons[codon_id]]]
+      }
+    }
+
+    #Paste the codons together
+    sequence <- paste(codons, collapse="")
+
+    #Return the sequence
+    return(sequence)
+  }
+
 
   make_VDJ_sample <- function(VDJ.sample.directory,
                               remove.divergent.cells,
@@ -165,8 +240,8 @@ VDJ_build <- function(VDJ.directory,
     # - remove.divergent.cells bool - if TRUE, cells with more than one VDJ transcript or more than one VJ transcript will be excluded. This could be due to multiple cells being trapped in one droplet or due to light chain dual expression (concerns ~2-5% of B cells, see DOI:10.1084/jem.181.3.1245). Defaults to FALSE.
     # - complete.cells.only bool - if TRUE, only cells with both a VDJ transcripts and a VJ transcript are included in the VDJ dataframe. Keeping only cells with 1 VDJ and 1 VJ transcript could be preferable for downstream analysis. Defaults to FALSE.
     # - trim.germlines bool - if TRUE, the raw germline sequences of each clone will be trimmed using the the consensus sequences of that clone as reference seqeunces (using BIostrings::pairwiseAlignment with the option "global-local" and a gap opening cost = gap.opening.cost). Defaults to FALSE.
-    # - gap.opening.cost float or Inf - the cost for opening a gap in Biostrings::pairwiseAlignment when aligning and trimming germline sequences. Defaults to Inf (gapless alignment).
-    # Author: Tudor-Stefan Cotet, Aurora Desideri Perea, Anamay Samant, Valentijn Tromp
+    # - gap.opening.cost float - the cost for opening a gap in Biostrings::pairwiseAlignment when aligning and trimming germline sequences. Defaults to 10.
+    # Authors: Tudor-Stefan Cotet, Aurora Desideri Perea, Anamay Samant, Valentijn Tromp
 
     # 1. Read in the following files from Cell Ranger output and store in list 'out':
     # [[1]]: 'filtered_contig_annotations.csv' contains high-level annotations of each high-confidence contig from cell-associated barcodes
@@ -192,7 +267,7 @@ VDJ_build <- function(VDJ.directory,
     out <- vector("list", 5)
 
     # Read 'filtered_contig_annotations.csv' file and store dataframe in out[[1]]
-    out[[1]] <- utils::read.csv(paste(VDJ.sample.directory,"filtered_contig_annotations.csv",sep=""),sep=",",header=TRUE)
+    out[[1]] <- utils::read.csv(paste(VDJ.sample.directory,"filtered_contig_annotations.csv",sep=""),sep=",",header=T)
     # Add "_aa" to column names with aa sequences for clarity
     colnames(out[[1]]) <- gsub(colnames(out[[1]]), pattern="^(fwr\\d|cdr\\d)$", replacement="\\1_aa")
     # Remove "raw_" from column names for consistency
@@ -203,14 +278,14 @@ VDJ_build <- function(VDJ.directory,
     # Remove "_" from 'v_gene', 'd_gene', 'j_gene', and 'c_gene' column
     colnames(out[[1]]) <- gsub(colnames(out[[1]]), pattern = "_gene", replacement="gene")
     # Concatenate nt and aa sequences of FWR1-4 and CDR1-3 regions and place concatenated sequence in new column in dataframe in out[[1]] (if FWR1-4 and CDR1-3 regions are annotated in 'filtered_contig_annotations.csv')
-    if(all(c("fwr1_nt","cdr1_nt","fwr2_nt","cdr2_nt","fwr3_nt","cdr3s_nt","fwr4_nt","fwr1_aa","cdr1_aa","fwr2_aa","cdr2_aa","fwr3_aa","cdr3s_aa","fwr4_aa") %in% colnames(out[[1]]))){
+    if(all(c("fwr1_nt","cdr1_nt","fwr2_nt","cdr2_nt","fwr3_nt","cdr3_nt","fwr4_nt","fwr1_aa","cdr1_aa","fwr2_aa","cdr2_aa","fwr3_aa","cdr3_aa","fwr4_aa") %in% colnames(out[[1]]))){
       out[[1]]$sequence_nt_trimmed <- paste0(out[[1]][["fwr1_nt"]], out[[1]][["cdr1_nt"]],
                                              out[[1]][["fwr2_nt"]], out[[1]][["cdr2_nt"]],
-                                             out[[1]][["fwr3_nt"]], out[[1]][["cdr3s_nt"]],
+                                             out[[1]][["fwr3_nt"]], out[[1]][["cdr3_nt"]],
                                              out[[1]][["fwr4_nt"]])
       out[[1]]$sequence_aa_trimmed <- paste0(out[[1]][["fwr1_aa"]], out[[1]][["cdr1_aa"]],
                                              out[[1]][["fwr2_aa"]], out[[1]][["cdr2_aa"]],
-                                             out[[1]][["fwr3_aa"]], out[[1]][["cdr3s_aa"]],
+                                             out[[1]][["fwr3_aa"]], out[[1]][["cdr3_aa"]],
                                              out[[1]][["fwr4_aa"]])
     # If FWR1-4 and CDR1-3 regions are not annotated (e.g., in older Cell Ranger versions where only the CDR3 sequence is annotated in 'filtered_contig_annotations.csv'), trimmed sequences are retrieved using the 'all_contig_annotations.json' file
     }else{
@@ -224,7 +299,7 @@ VDJ_build <- function(VDJ.directory,
           dplyr::rename(sequence_nt_trimmed = sequence_trimmed)
         # Translate trimmed nt sequences into aa sequences
         out[[1]]$sequence_aa_trimmed[which(!is.na(out[[1]]$sequence_nt_trimmed))]  <- sapply(out[[1]]$sequence_nt_trimmed[which(!is.na(out[[1]]$sequence_nt_trimmed))], function(x){
-          aa_sequence <- suppressWarnings(Biostrings::translate(Biostrings::DNAString(x)))
+          aa_sequence <- suppressWarnings(translate_DNA(x))
           return(as.character(aa_sequence))})
       # If the 'all_contig_annotations.json' file is absent in the sample directory, a warning message is returned and 'sequence_nt_trimmed' and 'sequence_aa_trimmed' columns are set to NA
       } else{
@@ -243,7 +318,7 @@ VDJ_build <- function(VDJ.directory,
     out[[2]]$contig_id <- gsub(rownames(out[[2]]), pattern="-1", replacement="")
 
     # Read 'consensus_annotations.csv' file and store in out[[3]]
-    out[[3]] <- utils::read.csv(paste(VDJ.sample.directory,"consensus_annotations.csv",sep=""),sep=",",header=TRUE)
+    out[[3]] <- utils::read.csv(paste(VDJ.sample.directory,"consensus_annotations.csv",sep=""),sep=",",header=T)
     # Add "_aa" to column names with aa sequences for clarity
     colnames(out[[3]]) <- gsub(colnames(out[[3]]), pattern="^(fwr\\d|cdr\\d)$", replacement="\\1_aa")
     # Modify consensus IDs by placing an underscore between 'consensus' and the subsequent number for consistency
@@ -253,16 +328,16 @@ VDJ_build <- function(VDJ.directory,
     # Remove "_" from 'v_gene', 'd_gene', 'j_gene', and 'c_gene' column
     colnames(out[[3]]) <- gsub(colnames(out[[3]]), pattern = "_gene", replacement="gene")
     # Concatenate nt and aa sequences of FWR1-4 and CDR1-3 regions and place concatenated sequence in new column in dataframe in out[[3]] (if FWR1-4 and CDR1-3 regions are annotated in 'consensus_annotations.csv')
-    if(all(c("fwr1_nt","cdr1_nt","fwr2_nt","cdr2_nt","fwr3_nt","cdr3s_nt","fwr4_nt","fwr1_aa","cdr1_aa","fwr2_aa","cdr2_aa","fwr3_aa","cdr3s_aa","fwr4_aa") %in% colnames(out[[3]]))){
+    if(all(c("fwr1_nt","cdr1_nt","fwr2_nt","cdr2_nt","fwr3_nt","cdr3_nt","fwr4_nt","fwr1_aa","cdr1_aa","fwr2_aa","cdr2_aa","fwr3_aa","cdr3_aa","fwr4_aa") %in% colnames(out[[3]]))){
       out[[3]]$consensus_nt_trimmed <- paste0(out[[3]][["fwr1_nt"]], out[[3]][["cdr1_nt"]],
                                               out[[3]][["fwr2_nt"]], out[[3]][["cdr2_nt"]],
-                                              out[[3]][["fwr3_nt"]], out[[3]][["cdr3s_nt"]],
+                                              out[[3]][["fwr3_nt"]], out[[3]][["cdr3_nt"]],
                                               out[[3]][["fwr4_nt"]])
       out[[3]]$consensus_aa_trimmed <- paste0(out[[3]][["fwr1_aa"]], out[[3]][["cdr1_aa"]],
                                               out[[3]][["fwr2_aa"]], out[[3]][["cdr2_aa"]],
-                                              out[[3]][["fwr3_aa"]], out[[3]][["cdr3s_aa"]],
+                                              out[[3]][["fwr3_aa"]], out[[3]][["cdr3_aa"]],
                                               out[[3]][["fwr4_aa"]])
-    # If FWR1-4 and CDR1-3 regions are not annotated (e.g., in older Cell Ranger versions where only the CDR3 sequence is annotated in 'consensus_nnotations.csv'), trimmed sequences are retrieved using the 'consensus_annotations.json' file
+    # If FWR1-4 and CDR1-3 regions are not annotated (e.g., in older Cell Ranger versions where only the CDR3 sequence is annotated in 'consensus_annotations.csv'), trimmed sequences are retrieved using the 'consensus_annotations.json' file
     }else{
       # Check if the 'consensus_annotations.json' file is present in the sample directory
       if(file.exists(paste0(VDJ.sample.directory,"consensus_annotations.json"))){
@@ -274,7 +349,7 @@ VDJ_build <- function(VDJ.directory,
           dplyr::rename(consensus_nt_trimmed = sequence_trimmed)
         # Translate trimmed nt sequences into aa sequences
         out[[3]]$consensus_aa_trimmed[which(!is.na(out[[3]]$consensus_nt_trimmed))]  <- sapply(out[[3]]$consensus_nt_trimmed[which(!is.na(out[[3]]$consensus_nt_trimmed))], function(x){
-          aa_sequence <- suppressWarnings(Biostrings::translate(Biostrings::DNAString(x)))
+          aa_sequence <- suppressWarnings(translate_DNA(x))
           return(as.character(aa_sequence))})
         # If the 'consensus_annotations.json' file is absent in the sample directory, a warning message is returned and 'consensus_nt_trimmed' and 'consensus_aa_trimmed' columns are set to NA
       } else{
@@ -318,10 +393,10 @@ VDJ_build <- function(VDJ.directory,
 
     # If 'trim.germlines' is set to TRUE, perform pairwise alignment with 'trim_seq' function in parallel with 'mapply'
     if(trim.germlines){
-      consensuses$germline_nt_trimmed <- mapply(trim_seq, consensuses$consensus_nt_trimmed, consensuses$germline_nt_raw)
+      consensuses$germline_nt_trimmed <- mapply(trim_seq, consensuses$consensus_nt_trimmed, consensuses$germline_nt_raw, gap.opening.cost)
       # Translate trimmed nt sequences into aa sequences
       consensuses$germline_aa_trimmed[which(!is.na(consensuses$germline_nt_trimmed))] <- sapply(consensuses$germline_nt_trimmed[which(!is.na(consensuses$germline_nt_trimmed))], function(x){
-        aa_sequence <- suppressWarnings(Biostrings::translate(Biostrings::DNAString(x)))
+        aa_sequence <- suppressWarnings(translate_DNA(x))
         return(as.character(aa_sequence))
       })
     # If 'trim.germlines' is set to FALSE (default), 'germline_nt_trimmed' and 'germline_aa_trimmed' columns are set to NA
@@ -347,7 +422,7 @@ VDJ_build <- function(VDJ.directory,
                          "fwr2_nt","fwr2_aa",
                          "cdr2_nt","cdr2_aa",
                          "fwr3_nt","fwr3_aa",
-                         "cdr3s_nt","cdr3s_aa",
+                         "cdr3_nt","cdr3_aa",
                          "fwr4_nt","fwr4_aa",
                          "sequence_nt_raw",
                          "sequence_nt_trimmed",
@@ -441,54 +516,61 @@ VDJ_build <- function(VDJ.directory,
 
     # 5. Finalize VDJ dataframe
 
-    # Add column 'sample_id' to 'VDJ' dataframe and use name of sample directory folder - will also add a sample id as the index
+    # Add column 'sample_id' to 'VDJ' dataframe and use name of sample directory folder
     VDJ_df$sample_id <- basename(VDJ.sample.directory)
 
-    # Add column 'celltype' based on chains in 'VDJ_chain' and 'VJ_chain' column ("TRA" and "TRB" --> "T cell"; "IGH", "IGK", and "IGL" --> "B cell")
+    # Add column 'celltype' based on chains in 'VDJ_chain' and 'VJ_chain' column ("TRA", "TRB", "TRD", and TRG" --> "T cell"; "IGH", "IGK", and "IGL" --> "B cell")
     VDJ_df$celltype[stringr::str_detect(paste0(VDJ_df$VDJ_chain,VDJ_df$VJ_chain), "TR")] <- "T cell"
     VDJ_df$celltype[stringr::str_detect(paste0(VDJ_df$VDJ_chain,VDJ_df$VJ_chain), "IG")] <- "B cell"
 
+    # Add the 'isotype' column based on the 'VDJ_cgene' column
+    VDJ_df <- VDJ_df |>
+      dplyr::mutate(
+        isotype = ifelse(celltype == "B cell",
+                         sub("^IGH([A-Z])([0-9])([A-Z]*)$", "Ig\\1\\2", VDJ_cgene),
+                         NA))
+
     # Add column 'clonotype_frequencies'
     VDJ_df$clonotype_frequency <- unlist(lapply(VDJ_df$clonotype_id, function(x) length(which(VDJ_df$clonotype_id == x))))
 
     # Specify order of columns in 'VDJ_df'
-    new_order <- c("sample_id","barcode","celltype",
-                   "VDJ_contig_id","VJ_contig_id",
-                   "VDJ_consensus_id","VJ_consensus_id",
-                   "clonotype_id","clonotype_frequency",
+    new_order <- c("sample_id", "barcode", "celltype", "isotype",
+                   "VDJ_contig_id", "VJ_contig_id",
+                   "VDJ_consensus_id", "VJ_consensus_id",
+                   "clonotype_id", "clonotype_frequency",
 
-                   "VDJ_chain","VDJ_chain_count","VDJ_umis",
-                   "VDJ_vgene","VDJ_dgene","VDJ_jgene","VDJ_cgene",
-                   "VDJ_fwr1_nt","VDJ_fwr1_aa",
-                   "VDJ_cdr1_nt","VDJ_cdr1_aa",
-                   "VDJ_fwr2_nt","VDJ_fwr2_aa",
-                   "VDJ_cdr2_nt","VDJ_cdr2_aa",
-                   "VDJ_fwr3_nt","VDJ_fwr3_aa",
-                   "VDJ_cdr3s_nt","VDJ_cdr3s_aa",
-                   "VDJ_fwr4_nt","VDJ_fwr4_aa",
-                   "VDJ_sequence_nt_raw","VDJ_sequence_nt_trimmed","VDJ_sequence_aa_trimmed",
-                   "VDJ_consensus_nt_raw","VDJ_consensus_nt_trimmed","VDJ_consensus_aa_trimmed",
-                   "VDJ_germline_nt_raw","VDJ_germline_nt_trimmed","VDJ_germline_aa_trimmed",
+                   "VDJ_chain", "VDJ_chain_count", "VDJ_umis",
+                   "VDJ_vgene", "VDJ_dgene", "VDJ_jgene", "VDJ_cgene",
+                   "VDJ_fwr1_nt", "VDJ_fwr1_aa",
+                   "VDJ_cdr1_nt", "VDJ_cdr1_aa",
+                   "VDJ_fwr2_nt", "VDJ_fwr2_aa",
+                   "VDJ_cdr2_nt", "VDJ_cdr2_aa",
+                   "VDJ_fwr3_nt", "VDJ_fwr3_aa",
+                   "VDJ_cdr3_nt", "VDJ_cdr3_aa",
+                   "VDJ_fwr4_nt", "VDJ_fwr4_aa",
+                   "VDJ_sequence_nt_raw", "VDJ_sequence_nt_trimmed", "VDJ_sequence_aa_trimmed",
+                   "VDJ_consensus_nt_raw", "VDJ_consensus_nt_trimmed", "VDJ_consensus_aa_trimmed",
+                   "VDJ_germline_nt_raw", "VDJ_germline_nt_trimmed", "VDJ_germline_aa_trimmed",
 
-                   "VJ_chain","VJ_chain_count","VJ_umis",
-                   "VJ_vgene","VJ_jgene","VJ_cgene",
-                   "VJ_fwr1_nt","VJ_fwr1_aa",
-                   "VJ_cdr1_nt","VJ_cdr1_aa",
-                   "VJ_fwr2_nt","VJ_fwr2_aa",
-                   "VJ_cdr2_nt","VJ_cdr2_aa",
-                   "VJ_fwr3_nt","VJ_fwr3_aa",
-                   "VJ_cdr3s_nt","VJ_cdr3s_aa",
-                   "VJ_fwr4_nt","VJ_fwr4_aa",
-                   "VJ_sequence_nt_raw","VJ_sequence_nt_trimmed","VJ_sequence_aa_trimmed",
-                   "VJ_consensus_nt_raw","VJ_consensus_nt_trimmed","VJ_consensus_aa_trimmed",
-                   "VJ_germline_nt_raw","VJ_germline_nt_trimmed","VJ_germline_aa_trimmed")
+                   "VJ_chain", "VJ_chain_count", "VJ_umis",
+                   "VJ_vgene", "VJ_jgene", "VJ_cgene",
+                   "VJ_fwr1_nt", "VJ_fwr1_aa",
+                   "VJ_cdr1_nt", "VJ_cdr1_aa",
+                   "VJ_fwr2_nt", "VJ_fwr2_aa",
+                   "VJ_cdr2_nt", "VJ_cdr2_aa",
+                   "VJ_fwr3_nt", "VJ_fwr3_aa",
+                   "VJ_cdr3_nt", "VJ_cdr3_aa",
+                   "VJ_fwr4_nt", "VJ_fwr4_aa",
+                   "VJ_sequence_nt_raw", "VJ_sequence_nt_trimmed", "VJ_sequence_aa_trimmed",
+                   "VJ_consensus_nt_raw", "VJ_consensus_nt_trimmed", "VJ_consensus_aa_trimmed",
+                   "VJ_germline_nt_raw", "VJ_germline_nt_trimmed", "VJ_germline_aa_trimmed")
     VDJ_df <- VDJ_df[, new_order]
 
     # Reorder rows in 'VDJ_df' dataframe by 'clonotype_id'
     VDJ_df <- VDJ_df |>
       dplyr::arrange(as.integer(stringr::str_extract(clonotype_id, "\\d+")))
 
-    # Combinine 'VDJ_df' dataframe, 'warnings' list, and 'filtering_counts' dataframe in 'output' list
+    # Combine 'VDJ_df' dataframe, 'warnings' list, and 'filtering_counts' dataframe in 'output' list
     output <- list(VDJ_df = VDJ_df, warnings = warnings, filtering = filtering_counts)
 
     # Return 'output' list
@@ -554,12 +636,14 @@ VDJ_build <- function(VDJ.directory,
   filtering_output <- do.call(rbind, lapply(output_list, function(x) x$filtering))
   # Print 'filtering_output' to show number of cells/barcodes excluded (if 'remove.divergent.cells' and/or 'complete.cells.only' is/are set to TRUE)
   message("Warning: Please be aware of the number of cells excluded, when 'remove.divergent.cells' or 'complete.cells.only' is set to TRUE:")
-  message(knitr::kable(filtering_output))
+  print(knitr::kable(filtering_output))
 
   # Select and row bind VDJ dataframes in 'output_list'
   VDJ_output <- do.call(rbind, lapply(output_list, function(x) x$VDJ_df))
+
   # Remove rownames from 'VDJ_output'
   rownames(VDJ_output) <- NULL
+
   # Ensure every missing value and empty string are set to NA
   VDJ_output[VDJ_output == 'None'] <- NA
   VDJ_output[VDJ_output == 'NA'] <- NA
